==> open-cluster-management-apps-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/PackageFilterFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PackageFilterFluent<A extends PackageFilterFluent<A>> extends BaseFluent<A>{
  public PackageFilterFluent() {
  }
  
  public PackageFilterFluent(PackageFilter instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> annotations;
  private LocalObjectReferenceBuilder filterRef;
  private LabelSelectorBuilder labelSelector;
  private String version;
  
  protected void copyInstance(PackageFilter instance) {
    instance = (instance != null ? instance : new PackageFilter());
    if (instance != null) {
          this.withAnnotations(instance.getAnnotations());
          this.withFilterRef(instance.getFilterRef());
          this.withLabelSelector(instance.getLabelSelector());
          this.withVersion(instance.getVersion());
          this.withAnnotations(instance.getAnnotations());
          this.withFilterRef(instance.getFilterRef());
          this.withLabelSelector(instance.getLabelSelector());
          this.withVersion(instance.getVersion());
        }
  }
  
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) {
      this.annotations = null;
    } else {
      this.annotations = new LinkedHashMap(annotations);
    }
    return (A) this;
  }
  
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  
  public LocalObjectReference buildFilterRef() {
    return this.filterRef != null ? this.filterRef.build() : null;
  }
  
  public A withFilterRef(LocalObjectReference filterRef) {
    this._visitables.remove(this.filterRef);
    if (filterRef != null) {
        this.filterRef = new LocalObjectReferenceBuilder(filterRef);
        this._visitables.get("filterRef").add(this.filterRef);
    } else {
        this.filterRef = null;
        this._visitables.get("filterRef").remove(this.filterRef);
    }
    return (A) this;
  }
  
  public boolean hasFilterRef() {
    return this.filterRef != null;
  }
  
  public A withNewFilterRef(String name) {
    return (A)withFilterRef(new LocalObjectReference(name));
  }
  
  public FilterRefNested<A> withNewFilterRef() {
    return new FilterRefNested(null);
  }
  
  public FilterRefNested<A> withNewFilterRefLike(LocalObjectReference item) {
    return new FilterRefNested(item);
  }
  
  public FilterRefNested<A> editFilterRef() {
    return withNewFilterRefLike(java.util.Optional.ofNullable(buildFilterRef()).orElse(null));
  }
  
  public FilterRefNested<A> editOrNewFilterRef() {
    return withNewFilterRefLike(java.util.Optional.ofNullable(buildFilterRef()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  
  public FilterRefNested<A> editOrNewFilterRefLike(LocalObjectReference item) {
    return withNewFilterRefLike(java.util.Optional.ofNullable(buildFilterRef()).orElse(item));
  }
  
  public LabelSelector buildLabelSelector() {
    return this.labelSelector != null ? this.labelSelector.build() : null;
  }
  
  public A withLabelSelector(LabelSelector labelSelector) {
    this._visitables.remove(this.labelSelector);
    if (labelSelector != null) {
        this.labelSelector = new LabelSelectorBuilder(labelSelector);
        this._visitables.get("labelSelector").add(this.labelSelector);
    } else {
        this.labelSelector = null;
        this._visitables.get("labelSelector").remove(this.labelSelector);
    }
    return (A) this;
  }
  
  public boolean hasLabelSelector() {
    return this.labelSelector != null;
  }
  
  public LabelSelectorNested<A> withNewLabelSelector() {
    return new LabelSelectorNested(null);
  }
  
  public LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item) {
    return new LabelSelectorNested(item);
  }
  
  public LabelSelectorNested<A> editLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(null));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item) {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(item));
  }
  
  public String getVersion() {
    return this.version;
  }
  
  public A withVersion(String version) {
    this.version = version;
    return (A) this;
  }
  
  public boolean hasVersion() {
    return this.version != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PackageFilterFluent that = (PackageFilterFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;
    if (!java.util.Objects.equals(filterRef, that.filterRef)) return false;
    if (!java.util.Objects.equals(labelSelector, that.labelSelector)) return false;
    if (!java.util.Objects.equals(version, that.version)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(annotations,  filterRef,  labelSelector,  version,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (filterRef != null) { sb.append("filterRef:"); sb.append(filterRef + ","); }
    if (labelSelector != null) { sb.append("labelSelector:"); sb.append(labelSelector + ","); }
    if (version != null) { sb.append("version:"); sb.append(version); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterRefNested<N> extends LocalObjectReferenceFluent<FilterRefNested<N>> implements Nested<N>{
    FilterRefNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    
    public N and() {
      return (N) PackageFilterFluent.this.withFilterRef(builder.build());
    }
    
    public N endFilterRef() {
      return and();
    }
    
  
  }
  public class LabelSelectorNested<N> extends LabelSelectorFluent<LabelSelectorNested<N>> implements Nested<N>{
    LabelSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) PackageFilterFluent.this.withLabelSelector(builder.build());
    }
    
    public N endLabelSelector() {
      return and();
    }
    
  
  }

}

==> open-cluster-management-apps-model-6.13.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/PackageFilterFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PackageFilterFluent<A extends PackageFilterFluent<A>> extends BaseFluent<A>{
  public PackageFilterFluent() {
  }
  
  public PackageFilterFluent(PackageFilter instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> annotations;
  private LocalObjectReferenceBuilder filterRef;
  private LabelSelectorBuilder labelSelector;
  private String version;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PackageFilter instance) {
    instance = (instance != null ? instance : new PackageFilter());
    if (instance != null) {
          this.withAnnotations(instance.getAnnotations());
          this.withFilterRef(instance.getFilterRef());
          this.withLabelSelector(instance.getLabelSelector());
          this.withVersion(instance.getVersion());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) {
      this.annotations = null;
    } else {
      this.annotations = new LinkedHashMap(annotations);
    }
    return (A) this;
  }
  
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  
  public LocalObjectReference buildFilterRef() {
    return this.filterRef != null ? this.filterRef.build() : null;
  }
  
  public A withFilterRef(LocalObjectReference filterRef) {
    this._visitables.remove("filterRef");
    if (filterRef != null) {
        this.filterRef = new LocalObjectReferenceBuilder(filterRef);
        this._visitables.get("filterRef").add(this.filterRef);
    } else {
        this.filterRef = null;
        this._visitables.get("filterRef").remove(this.filterRef);
    }
    return (A) this;
  }
  
  public boolean hasFilterRef() {
    return this.filterRef != null;
  }
  
  public A withNewFilterRef(String name) {
    return (A)withFilterRef(new LocalObjectReference(name));
  }
  
  public FilterRefNested<A> withNewFilterRef() {
    return new FilterRefNested(null);
  }
  
  public FilterRefNested<A> withNewFilterRefLike(LocalObjectReference item) {
    return new FilterRefNested(item);
  }
  
  public FilterRefNested<A> editFilterRef() {
    return withNewFilterRefLike(java.util.Optional.ofNullable(buildFilterRef()).orElse(null));
  }
  
  public FilterRefNested<A> editOrNewFilterRef() {
    return withNewFilterRefLike(java.util.Optional.ofNullable(buildFilterRef()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  
  public FilterRefNested<A> editOrNewFilterRefLike(LocalObjectReference item) {
    return withNewFilterRefLike(java.util.Optional.ofNullable(buildFilterRef()).orElse(item));
  }
  
  public LabelSelector buildLabelSelector() {
    return this.labelSelector != null ? this.labelSelector.build() : null;
  }
  
  public A withLabelSelector(LabelSelector labelSelector) {
    this._visitables.remove("labelSelector");
    if (labelSelector != null) {
        this.labelSelector = new LabelSelectorBuilder(labelSelector);
        this._visitables.get("labelSelector").add(this.labelSelector);
    } else {
        this.labelSelector = null;
        this._visitables.get("labelSelector").remove(this.labelSelector);
    }
    return (A) this;
  }
  
  public boolean hasLabelSelector() {
    return this.labelSelector != null;
  }
  
  public LabelSelectorNested<A> withNewLabelSelector() {
    return new LabelSelectorNested(null);
  }
  
  public LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item) {
    return new LabelSelectorNested(item);
  }
  
  public LabelSelectorNested<A> editLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(null));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item) {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(item));
  }
  
  public String getVersion() {
    return this.version;
  }
  
  public A withVersion(String version) {
    this.version = version;
    return (A) this;
  }
  
  public boolean hasVersion() {
    return this.version != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PackageFilterFluent that = (PackageFilterFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;
    if (!java.util.Objects.equals(filterRef, that.filterRef)) return false;
    if (!java.util.Objects.equals(labelSelector, that.labelSelector)) return false;
    if (!java.util.Objects.equals(version, that.version)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(annotations,  filterRef,  labelSelector,  version,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (filterRef != null) { sb.append("filterRef:"); sb.append(filterRef + ","); }
    if (labelSelector != null) { sb.append("labelSelector:"); sb.append(labelSelector + ","); }
    if (version != null) { sb.append("version:"); sb.append(version + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FilterRefNested<N> extends LocalObjectReferenceFluent<FilterRefNested<N>> implements Nested<N>{
    FilterRefNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    
    public N and() {
      return (N) PackageFilterFluent.this.withFilterRef(builder.build());
    }
    
    public N endFilterRef() {
      return and();
    }
    
  
  }
  public class LabelSelectorNested<N> extends LabelSelectorFluent<LabelSelectorNested<N>> implements Nested<N>{
    LabelSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) PackageFilterFluent.this.withLabelSelector(builder.build());
    }
    
    public N endLabelSelector() {
      return and();
    }
    
  
  }

}
